<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>Apollonius</name>
    <message>
        <location filename="../Apollonius.js" line="+1769"/>
        <source>Invalid radius</source>
        <translation>Ongeldig straal</translation>
    </message>
    <message>
        <location line="+51"/>
        <source>No solution</source>
        <translation>Geen oplossing</translation>
    </message>
</context>
<context>
    <name>DefaultAction</name>
    <message>
        <location filename="../DefaultAction.js" line="+89"/>
        <source>Select entity or region</source>
        <translation>Object of gebied selecteren</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Move entity or reference</source>
        <translation>Object of referentiepunt verplaatsen</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Set second corner</source>
        <translation>Tweede hoekpunt kiezen</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Specify target point of reference point</source>
        <translation>Bestemmingspunt voor referentiepunt kiezen</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Specify target point of selection</source>
        <translation>Bestemmingspunt voor selectie kiezen</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Move entity to desired location</source>
        <translation>Object verplaatsen</translation>
    </message>
    <message>
        <location line="+376"/>
        <source>Move Reference Point</source>
        <translation>Referentiepunt verplaatsen</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Move Selection</source>
        <translation>Selectie verplaatsen</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Move Entity</source>
        <translation>Object verplaatsen</translation>
    </message>
    <message>
        <location line="+127"/>
        <source>Editing block &apos;%1&apos;&lt;br&gt;Choose &lt;i&gt;Block &gt; Return to Main Drawing&lt;/i&gt; when done</source>
        <translation>Bewerken van blok &apos;%1&apos;&lt;br&gt;Kies &lt;i&gt;Blok &gt; Terug naar hoofdtekening&lt;/i&gt; als u klaar bent</translation>
    </message>
</context>
<context>
    <name>EAction</name>
    <message>
        <location filename="../EAction.js" line="+64"/>
        <source>Back</source>
        <translation>Terug</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+2075"/>
        <source>Cancel</source>
        <translation>Annuleer</translation>
    </message>
    <message>
        <location line="-1802"/>
        <location line="+136"/>
        <source>Active Tool:</source>
        <translation>Actief gereedschap:</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>None</source>
        <translation>Geen</translation>
    </message>
    <message>
        <location line="+662"/>
        <source>Options</source>
        <translation>Opties</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Main Tools</source>
        <translation>Hoofd gereedschappen</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>CAD Tools</source>
        <translation>CAD gereedschappen</translation>
    </message>
    <message>
        <location line="+710"/>
        <source>Entity is on a locked layer.</source>
        <translation>Object is op een vergrendelde laag.</translation>
    </message>
    <message>
        <location line="+232"/>
        <source>Length:</source>
        <translation>Lengte:</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Entity is not a block reference.</source>
        <translation>Object is niet een blok referentie.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line or arc.</source>
        <translation>Object is niet een lijn of boog.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc or polyline.</source>
        <translation>Entiteit is niet een lijn, boog of polylijn.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line.</source>
        <translation>Object is niet een lijn.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not an arc or circle.</source>
        <translation>Object is niet een boog of een cirkel.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc or circle.</source>
        <translation>Object is niet een lijn, boog of cirkel.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not an arc, circle or ellipse.</source>
        <translation>Object is niet een boog, cirkel of ellips.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle or ellipse.</source>
        <translation>Object is niet een lijn, boog, cirkel of ellips.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle, ellipse or polyline.</source>
        <translation>Object is niet een lijn, boog, cirkel, ellips of polylijn.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle, ellipse or spline.</source>
        <translation>Object is niet een lijn, boog, cirkel, ellips of spline.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle, ellipse, spline or polyline.</source>
        <translation>Object is niet een lijn, boog, cirkel, ellips, spline of polylijn.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a polyline.</source>
        <translation>Object is niet een polylijn.</translation>
    </message>
</context>
<context>
    <name>ShapeAlgorithms</name>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric circle(s).</source>
        <translation type="vanished">Radius gedaald tot onder 0 na %1 concentrische cirkel(s).</translation>
    </message>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric arc(s).</source>
        <translation type="vanished">Radius gedaald tot onder 0 na %1 concentrische boog(en).</translation>
    </message>
    <message>
        <location filename="../ShapeAlgorithms.js" line="+1413"/>
        <location line="+29"/>
        <source>At least two points are identical.</source>
        <translation>Ten minste twee punten zijn identiek.</translation>
    </message>
    <message>
        <location line="-22"/>
        <source>No circle possible.</source>
        <translation>Geen cirkel mogelijk.</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>No arc possible.</source>
        <translation>Geen boog mogelijk.</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Invalid number of segments: %1.</source>
        <translation>Ongeldig aantal segmenten: %1.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Invalid ellipse major / minor: %1 / %2.</source>
        <translation>Ongeldige ellips major / minor ratio: %1 / %2.</translation>
    </message>
</context>
<context>
    <name>WidgetFactory</name>
    <message>
        <location filename="../WidgetFactory.js" line="+1003"/>
        <source>Restore defaults</source>
        <translation>Standaardinstellingen herstellen</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Insert Symbol</source>
        <translation>Symbool invoegen</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Diameter</source>
        <translation>Diameter</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arc</source>
        <translation>Boog</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Degree</source>
        <translation>Graad</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plus/Minus</source>
        <translation>Plus/Minus</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Almost equal to</source>
        <translation>Bijna gelijk aan</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Asymptotically equal to</source>
        <translation>Asymptotisch gelijk aan</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pi</source>
        <translation>Pi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Square root</source>
        <translation>Vierkantswortel</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Phi</source>
        <translation>Phi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>phi</source>
        <translation>phi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Alt phi</source>
        <translation>Alt phi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ohm</source>
        <translation>Ohm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>omega</source>
        <translation>omega</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Multiplication</source>
        <translation>Vermenigvuldiging</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Division</source>
        <translation>Divisie</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Square</source>
        <translation>Kwadraat</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delta</source>
        <translation>Delta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Stacked text</source>
        <translation>Gestapelde tekst</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Measured value</source>
        <translation>Gemeten waarde</translation>
    </message>
    <message>
        <location line="+116"/>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Center</source>
        <translation>Middelpunt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Aligned</source>
        <translation>Uitgelijnd</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+7"/>
        <source>Middle</source>
        <translation>Midden</translation>
    </message>
    <message>
        <location line="-6"/>
        <source>Fit</source>
        <translation>Passen</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Top</source>
        <translation>Bovenkant</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Base</source>
        <translation>Basis</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom</source>
        <translation>Onderkant</translation>
    </message>
    <message>
        <location line="+7"/>
        <location line="+4"/>
        <source>Clockwise</source>
        <translation>Rechtsom</translation>
    </message>
    <message>
        <location line="-3"/>
        <location line="+4"/>
        <source>Counterclockwise</source>
        <translation>Linksom</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Preceding</source>
        <translation>Voorafgaand</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Above</source>
        <translation>Boven</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>None</source>
        <translation>Geen</translation>
    </message>
</context>
<context>
    <name>autostart</name>
    <message>
        <location filename="../autostart.js" line="+327"/>
        <source>Loading add-on translations...</source>
        <translation>Laden van add-on vertalingen...</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Loading add-ons...</source>
        <translation>Laden van add-ons...</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Initializing add-ons...</source>
        <translation>Initialiseren van add-ons...</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Initializing add-ons:</source>
        <translation>Initialiseren van add-ons:</translation>
    </message>
    <message>
        <source>Post-initializing add-ons...</source>
        <translation type="vanished">Post-initialiseren van add-ons...</translation>
    </message>
</context>
<context>
    <name>library</name>
    <message>
        <location filename="../library.js" line="+829"/>
        <source>Objects</source>
        <translation>Objecten</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Object</source>
        <translation>Object</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Unknown Objects</source>
        <translation>Onbekende objecten</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Unknown Object</source>
        <translation>Onbekende object</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Blocks</source>
        <translation>Blokken</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Block</source>
        <translation>Blok</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Layers</source>
        <translation>Laagen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Layer</source>
        <translation>Laag</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Layouts</source>
        <translation>Layouts</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Layout</source>
        <translation>Layout</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Linetypes</source>
        <translation>Lijntypen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Linetype</source>
        <translation>Lijntype</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Views</source>
        <translation>Weergaven</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>View</source>
        <translation>Weergave</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Entity</source>
        <translation>Object</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Entities</source>
        <translation>Objecten</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>3dFaces</source>
        <translation>3dFaces</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>3dFace</source>
        <translation>3dFace</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block References</source>
        <translation>Blok referenties</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Block Reference</source>
        <translation>Blok referentie</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block References and Attributes</source>
        <translation>Blok referenties en attributen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Block Reference and Attributes</source>
        <translation>Blok referentie en attributen</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Arcs</source>
        <translation>Bogen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Arc</source>
        <translation>Boog</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Attributes</source>
        <translation>Attributen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Attribute</source>
        <translation>Attribuut</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Attribute Definitions</source>
        <translation>Attribuut definities</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Attribute Definition</source>
        <translation>Attribuut definitie</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Circles</source>
        <translation>Cirkels</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Circle</source>
        <translation>Cirkel</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Dimensions</source>
        <translation>Bematingen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Dimension</source>
        <translation>Bemating</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Aligned Dimensions</source>
        <translation>Uitgelijnde bemating</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Aligned Dimension</source>
        <translation>Uitgelijnde bemating</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Angular Dimensions</source>
        <translation>Hoek bematingen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Angular Dimension</source>
        <translation>Hoek bemating</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>2 Line Angular Dimensions</source>
        <translation>2 lijnen hoek bematingen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>2 Line Angular Dimension</source>
        <translation>2 lijnen hoek bemating</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>3 Point Angular Dimensions</source>
        <translation>3 punt hoek bematingen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>3 Point Angular Dimension</source>
        <translation>3 punt hoek bemating</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Arc Dimension</source>
        <translation>Boog bemating</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Diametric Dimensions</source>
        <translation>Diametrische bemating</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Diametric Dimension</source>
        <translation>Diametrische Maat</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Ordinate Dimensions</source>
        <translation>Ordinaat bematingen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Ordinate Dimension</source>
        <translation>Ordinaat bemating</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Rotated Dimensions</source>
        <translation>Gedraaide bematingen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Rotated Dimension</source>
        <translation>Gedraaide bemating</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Radial Dimensions</source>
        <translation>Radiale bematingen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Radial Dimension</source>
        <translation>Radiale bemating</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Ellipses</source>
        <translation>Ellipsen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Ellipse</source>
        <translation>Ellips</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Hatches</source>
        <translation>Arceringen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Hatch</source>
        <translation>Arcering</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Images</source>
        <translation>Afbeeldingen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Image</source>
        <translation>Afbeelding</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Leaders</source>
        <translation>Verwijslijnen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Leader</source>
        <translation>Verwijslijn</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Lines</source>
        <translation>Lijnen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Line</source>
        <translation>Lijn</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Infinite Lines</source>
        <translation>Oneindige lijnen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Infinite Line</source>
        <translation>Oneindig lijn</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Rays</source>
        <translation>Stralen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Ray</source>
        <translation>Straal</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Points</source>
        <translation>Punten</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Point</source>
        <translation>Punt</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Polylines</source>
        <translation>Polylijnen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Polyline</source>
        <translation>Polylijn</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Solids</source>
        <translation>Vaste lichamen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Solid</source>
        <translation>Vaste licham</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Traces</source>
        <translation>Traces</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Trace</source>
        <translation>Trace</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Faces</source>
        <translation>Oppervlakken</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Face</source>
        <translation>Oppervlak</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Splines</source>
        <translation>Splines</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Spline</source>
        <translation>Spline</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Text based</source>
        <translation>Tekst gebaseerd</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Texts</source>
        <translation>Teksten</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Viewports</source>
        <translation>Weergaven</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Viewport</source>
        <translation>Weergave</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Unknown Entities</source>
        <translation>Onbekende objecten</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Unknown Entity</source>
        <translation>Onbekende object</translation>
    </message>
</context>
<context>
    <name>simple_modify</name>
    <message>
        <location filename="../simple_modify.js" line="+301"/>
        <source>First entity cannot be trimmed.</source>
        <translation>Eerste object kan niet worden getrimmed.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Entity cannot be trimmed.</source>
        <translation>Object kan niet worden getrimmed.</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Second entity cannot be trimmed.</source>
        <translation>Tweede object kan niet worden getrimmed.</translation>
    </message>
</context>
</TS>
